@@ -1,4 +1,4 @@
-from bruhcolor.bruhcolor import ATTRIBUTES, RESET_8, RESET_256, COLORS_8, COLORS_256, HIGHLIGHTS_8, HIGHLIGHTS_256, bruhcolored, color_codes, bruhcolorwrapper, colors, VERSION
+from bruhcolor.bruhcolor import ATTRIBUTES, RESET_8, RESET_256, COLORS_8, COLORS_256, HIGHLIGHTS_8, HIGHLIGHTS_256, bruhcolored, color_codes, bruhcolorwrapper, colors, VERSION, valid_effects
 
 __all__ = [
     "ATTRIBUTES",
@@ -12,5 +12,6 @@ __all__ = [
     "bruhcolorwrapper",
     "colors",
     "color_codes",
-    "VERSION"
+    "VERSION",
+    "valid_effects"
 ]
\ No newline at end of file
